==> openconfig-models-15.1.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/vlan/rev190416/vlan/logical/top/VlanBuilder.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.top;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.VlanLogicalEgressMappingTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.VlanLogicalIngressMappingTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.VlanLogicalMatchTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.egress.mapping.top.EgressMapping;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.ingress.mapping.top.IngressMapping;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.match.top.Match;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.top.vlan.Config;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.top.vlan.State;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link VlanBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     VlanBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new VlanBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of VlanBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see VlanBuilder
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class VlanBuilder implements Builder<Vlan> {

    private Config _config;
    private EgressMapping _egressMapping;
    private IngressMapping _ingressMapping;
    private Match _match;
    private State _state;


    Map<Class<? extends Augmentation<Vlan>>, Augmentation<Vlan>> augmentation = Collections.emptyMap();

    public VlanBuilder() {
    }
    
    
    
    public VlanBuilder(VlanLogicalMatchTop arg) {
        this._match = arg.getMatch();
    }
    
    public VlanBuilder(VlanLogicalIngressMappingTop arg) {
        this._ingressMapping = arg.getIngressMapping();
    }
    
    public VlanBuilder(VlanLogicalEgressMappingTop arg) {
        this._egressMapping = arg.getEgressMapping();
    }

    public VlanBuilder(Vlan base) {
        Map<Class<? extends Augmentation<Vlan>>, Augmentation<Vlan>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._config = base.getConfig();
        this._egressMapping = base.getEgressMapping();
        this._ingressMapping = base.getIngressMapping();
        this._match = base.getMatch();
        this._state = base.getState();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>VlanLogicalEgressMappingTop</li>
     * <li>VlanLogicalMatchTop</li>
     * <li>VlanLogicalIngressMappingTop</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof VlanLogicalEgressMappingTop) {
            this._egressMapping = ((VlanLogicalEgressMappingTop)arg).getEgressMapping();
            isValidArg = true;
        }
        if (arg instanceof VlanLogicalMatchTop) {
            this._match = ((VlanLogicalMatchTop)arg).getMatch();
            isValidArg = true;
        }
        if (arg instanceof VlanLogicalIngressMappingTop) {
            this._ingressMapping = ((VlanLogicalIngressMappingTop)arg).getIngressMapping();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[VlanLogicalEgressMappingTop, VlanLogicalMatchTop, VlanLogicalIngressMappingTop]");
    }

    public Config getConfig() {
        return _config;
    }
    
    public EgressMapping getEgressMapping() {
        return _egressMapping;
    }
    
    public IngressMapping getIngressMapping() {
        return _ingressMapping;
    }
    
    public Match getMatch() {
        return _match;
    }
    
    public State getState() {
        return _state;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Vlan>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public VlanBuilder setConfig(final Config value) {
        this._config = value;
        return this;
    }
    
    public VlanBuilder setEgressMapping(final EgressMapping value) {
        this._egressMapping = value;
        return this;
    }
    
    public VlanBuilder setIngressMapping(final IngressMapping value) {
        this._ingressMapping = value;
        return this;
    }
    
    public VlanBuilder setMatch(final Match value) {
        this._match = value;
        return this;
    }
    
    public VlanBuilder setState(final State value) {
        this._state = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public VlanBuilder addAugmentation(Augmentation<Vlan> augmentation) {
        Class<? extends Augmentation<Vlan>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public VlanBuilder removeAugmentation(Class<? extends Augmentation<Vlan>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Vlan build() {
        return new VlanImpl(this);
    }

    private static final class VlanImpl
        extends AbstractAugmentable<Vlan>
        implements Vlan {
    
        private final Config _config;
        private final EgressMapping _egressMapping;
        private final IngressMapping _ingressMapping;
        private final Match _match;
        private final State _state;
    
        VlanImpl(VlanBuilder base) {
            super(base.augmentation);
            this._config = base.getConfig();
            this._egressMapping = base.getEgressMapping();
            this._ingressMapping = base.getIngressMapping();
            this._match = base.getMatch();
            this._state = base.getState();
        }
    
        @Override
        public Config getConfig() {
            return _config;
        }
        
        @Override
        public EgressMapping getEgressMapping() {
            return _egressMapping;
        }
        
        @Override
        public IngressMapping getIngressMapping() {
            return _ingressMapping;
        }
        
        @Override
        public Match getMatch() {
            return _match;
        }
        
        @Override
        public State getState() {
            return _state;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = Vlan.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return Vlan.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return Vlan.bindingToString(this);
        }
    }
}

==> openconfig-models-15.3.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/vlan/rev190416/vlan/logical/top/VlanBuilder.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.top;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.VlanLogicalEgressMappingTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.VlanLogicalIngressMappingTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.VlanLogicalMatchTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.egress.mapping.top.EgressMapping;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.ingress.mapping.top.IngressMapping;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.match.top.Match;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.top.vlan.Config;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.vlan.rev190416.vlan.logical.top.vlan.State;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link Vlan} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     Vlan createVlan(int fooXyzzy, int barBaz) {
 *         return new VlanBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of Vlan, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see Vlan
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class VlanBuilder implements Builder<Vlan> {

    private Config _config;
    private EgressMapping _egressMapping;
    private IngressMapping _ingressMapping;
    private Match _match;
    private State _state;


    Map<Class<? extends Augmentation<Vlan>>, Augmentation<Vlan>> augmentation = Collections.emptyMap();

    public VlanBuilder() {
    }
    
    
    
    public VlanBuilder(VlanLogicalMatchTop arg) {
        this._match = arg.getMatch();
    }
    
    public VlanBuilder(VlanLogicalIngressMappingTop arg) {
        this._ingressMapping = arg.getIngressMapping();
    }
    
    public VlanBuilder(VlanLogicalEgressMappingTop arg) {
        this._egressMapping = arg.getEgressMapping();
    }

    public VlanBuilder(Vlan base) {
        Map<Class<? extends Augmentation<Vlan>>, Augmentation<Vlan>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._config = base.getConfig();
        this._egressMapping = base.getEgressMapping();
        this._ingressMapping = base.getIngressMapping();
        this._match = base.getMatch();
        this._state = base.getState();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>VlanLogicalEgressMappingTop</li>
     * <li>VlanLogicalMatchTop</li>
     * <li>VlanLogicalIngressMappingTop</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof VlanLogicalEgressMappingTop) {
            this._egressMapping = ((VlanLogicalEgressMappingTop)arg).getEgressMapping();
            isValidArg = true;
        }
        if (arg instanceof VlanLogicalMatchTop) {
            this._match = ((VlanLogicalMatchTop)arg).getMatch();
            isValidArg = true;
        }
        if (arg instanceof VlanLogicalIngressMappingTop) {
            this._ingressMapping = ((VlanLogicalIngressMappingTop)arg).getIngressMapping();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[VlanLogicalEgressMappingTop, VlanLogicalMatchTop, VlanLogicalIngressMappingTop]");
    }

    public Config getConfig() {
        return _config;
    }
    
    public EgressMapping getEgressMapping() {
        return _egressMapping;
    }
    
    public IngressMapping getIngressMapping() {
        return _ingressMapping;
    }
    
    public Match getMatch() {
        return _match;
    }
    
    public State getState() {
        return _state;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Vlan>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public VlanBuilder setConfig(final Config value) {
        this._config = value;
        return this;
    }
    
    public VlanBuilder setEgressMapping(final EgressMapping value) {
        this._egressMapping = value;
        return this;
    }
    
    public VlanBuilder setIngressMapping(final IngressMapping value) {
        this._ingressMapping = value;
        return this;
    }
    
    public VlanBuilder setMatch(final Match value) {
        this._match = value;
        return this;
    }
    
    public VlanBuilder setState(final State value) {
        this._state = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public VlanBuilder addAugmentation(Augmentation<Vlan> augmentation) {
        Class<? extends Augmentation<Vlan>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public VlanBuilder removeAugmentation(Class<? extends Augmentation<Vlan>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Vlan build() {
        return new VlanImpl(this);
    }

    private static final class VlanImpl
        extends AbstractAugmentable<Vlan>
        implements Vlan {
    
        private final Config _config;
        private final EgressMapping _egressMapping;
        private final IngressMapping _ingressMapping;
        private final Match _match;
        private final State _state;
    
        VlanImpl(VlanBuilder base) {
            super(base.augmentation);
            this._config = base.getConfig();
            this._egressMapping = base.getEgressMapping();
            this._ingressMapping = base.getIngressMapping();
            this._match = base.getMatch();
            this._state = base.getState();
        }
    
        @Override
        public Config getConfig() {
            return _config;
        }
        
        @Override
        public EgressMapping getEgressMapping() {
            return _egressMapping;
        }
        
        @Override
        public IngressMapping getIngressMapping() {
            return _ingressMapping;
        }
        
        @Override
        public Match getMatch() {
            return _match;
        }
        
        @Override
        public State getState() {
            return _state;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = Vlan.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return Vlan.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return Vlan.bindingToString(this);
        }
    }
}
